%%%% #################################################
%%%% COMSATS University Islamabad (CUI): Synopsis Template Ver 4.0
%%%% Made by: Dr. Atiq ur Rehman,
%%%%		Department of Mathematics, CUI, Attock Campus
%%%% Webpage: http://www.mathcity.org/atiq
%%%% This file is available online at http://www.mathcity.org/cui
%%%% Created on September 11, 2019 ########################
%%%% Version 1.0 Just Created the whole class file #################
%%%% Version 2.0 Modified for CUI ##########################
%%%% Version 3.0 Modified at Line 100 & 108 for Name Space ##########
%%%% Version 4.0 Modified for new style, October 05, 2023 ##########
%%%% #################################################
\ProvidesClass{cui-synopsis}
\LoadClass[12pt]{article}
\RequirePackage{graphicx, framed, fancyhdr, lastpage, array, geometry}
\geometry{a4paper, total={160mm,247mm}, left=25mm, top=25mm,}
\pagestyle{fancy}
\fancyhf{}
\lfoot{\\{\footnotesize Student Name:  \@name\\ Registration No.: \@registration}}\cfoot{{\footnotesize \thepage} }\rfoot{\footnotesize{\underline{\hspace{3.5cm}} \\Supervisor's Signature}}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
%% For wrapping text in tabular STARTED
\newcolumntype{L}[1]{>{\raggedright\let\newline\\\arraybackslash\hspace{0pt}}m{#1}}
\newcolumntype{C}[1]{>{\centering\let\newline\\\arraybackslash\hspace{0pt}}m{#1}}
\newcolumntype{R}[1]{>{\raggedleft\let\newline\\\arraybackslash\hspace{0pt}}m{#1}}
%% For wrapping text in tabular ENDED
\newlength{\framedline}
\setlength{\framedline}{1.129\textwidth}
\let\oldrule\rule
\renewcommand{\rule}[2]{
	\hspace*{-9pt}\oldrule{\framedline}{0.4pt}\newline
}
% Here we define margin, line spacing and etc.
\linespread{1.3}	% double spaces lines
%\textwidth 6.2truein  % These 4 commands define more efficient margins
%\textheight 10truein
%\oddsidemargin  0in
%\evensidemargin 0in
%\topmargin -0.8in
\parindent 0pt	% let's not indent paragraphs
\parskip 5pt  % Also, a bit of space between paragraphs

% End of :Here we define margin, line spacing and etc.:

% \name, \title are defined in report; here are the rest of the
% front matter defining macros
\def\name#1{\gdef\@name{#1}}
\def\registration#1{\gdef\@registration{#1}}
\def\program#1{\gdef\@program{#1}}
\def\area#1{\gdef\@area{#1}}
\def\campus#1{\gdef\@campus{#1}}
\def\department#1{\gdef\@department{#1}}
\def\admission#1{\gdef\@admission{#1}}
\def\submission#1{\gdef\@submission{#1}}
\def\supervisor#1{\gdef\@supervisor{#1}}
\def\cosupervisor#1{\gdef\@cosupervisor{#1}}
\def\membera#1{\gdef\@membera{#1}}
\def\memberb#1{\gdef\@memberb{#1}}

% Title page has been defined here.
%% Header is started from here
\renewcommand{\maketitle}{%
\begin{minipage}[c]{.13\linewidth}
\includegraphics[width=\linewidth]{cui-logo.png}
\end{minipage}\hfill
\begin{minipage}[c]{.83\linewidth}
\begin{center}
{\Large\textbf{COMSATS University Islamabad}}\\
{\large Synopsis for MS \makebox[0pt][l]{$\square$}\raisebox{.15ex}{\hspace{0.1em}$\checkmark$}  Ph.D. $\Box$ }
\end{center}
\end{minipage} \vspace{0.1in}
%% Header completed and information table started from here and space given below matters:

{\renewcommand{\arraystretch}{1.2}
\begin{tabular}{|p{1.525in}|p{1.525in}|p{1.525in}|p{1.525in}|}
	\hline
	\multicolumn{2}{|L{2.7in}|}{Name: \@name} & \multicolumn{2}{L{3.3in}|}{Registration No.: \@registration}  \\
	\hline
	\multicolumn{2}{|L{2.7in}|}{Program: \@program}  & \multicolumn{2}{L{3.3in}|}{Area of Specialization (if any as per approved SoS):\@area  }  \\
	\hline
    \multicolumn{2}{|L{2.7in}|}{Department: \@department}  & \multicolumn{2}{L{3.3in}|}{Campus: \@campus}  \\
	\hline
	\multicolumn{2}{|L{2.7in}|}{Date of admission: \@admission}  & \multicolumn{2}{L{3.3in}|}{Date of synopsis submission: \@submission}  \\
	\hline
	\multicolumn{4}{|L{6.2in}|}{Proposed Title of the Thesis: (Use title case capitalization): \@title}  \\
	\hline
	\multicolumn{4}{|c|}{\bf Supervisory Committee}  \\
	\hline
	\multicolumn{3}{|c|}{Name and Designation}  & \multicolumn{1}{c|}{Role} \\
	\hline
	\multicolumn{3}{|L{4.2in}|}{\@supervisor} & Supervisor \\
	\hline
	\multicolumn{3}{|L{4.2in}|}{\@cosupervisor} & Cosupervisor/Member \\
	\hline
	\multicolumn{3}{|L{4.2in}|}{\@membera} & Member \\
	\hline
	\multicolumn{3}{|L{4.2in}|}{\@memberb} & Member \\
	\hline
\end{tabular}}
\vspace{0.5cm}

\hfill Student's Signature: \underline{\hspace{4cm}}
\vspace{-0.40cm}
}

% Clsoing of the synopsis is defined here.
\newcommand{\closing}{%
\newpage
\underline{PART-2}
\begin{framed}
\textbf{\underline{Signature by the Student:}}

\vspace{1.2cm}

\begin{tabular}{l@{} p{5.6cm} @{\hspace{0.2em}}l@{} p{2.6cm} @{\hspace{0.2em}}l@{} p{2.4cm}}
Name: & $\,$ \@name \vspace{0.05cm} \hrule & Signature: & $\,$ \vspace{0.05cm} \hrule & Date: & $\,\,$\@date \vspace{0.05cm} \hrule \\
\end{tabular}


\textbf{\underline{Recommendation by the Research Supervisor}}

\vspace{1.2cm}
\begin{tabular}{l@{} p{5.6cm} @{\hspace{0.2em}}l@{} p{2.6cm} @{\hspace{0.2em}}l@{} p{2.4cm}}
Name: & $\,$ \@supervisor \vspace{0.05cm} \hrule & Signature: & $\,$ \vspace{0.05cm} \hrule & Date: & $\,$ \vspace{0.05cm} \hrule \\
\end{tabular}

\rule{}

\textbf{\underline{Signed by Supervisory Committee}} (Applicable for PhD students only)
\vspace{0.5cm}

\begin{tabular}{|p{0.8cm}|p{6cm}|p{2.5cm}|p{3.5cm}|}
\hline
S. \# & Name of Committee Member & Designation & Signature and Date \\
	\hline
	1 & & & \\
	\hline
	2 & & &  \\
	\hline
	3 & & &  \\
	\hline
\end{tabular}

\vspace{0.5cm}
\textbf{\underline{Approved by Departmental  Advisory Committee}}

Certified that the synopsis has been seen by members of DAC and considered it suitable for putting up to BASAR.

\vspace{0.5cm}
Secretary \\ Departmental  Advisory Committee

\vspace{0.5cm}

Name: \line(1,0){160} \hfill Signature: \line(1,0){130}

Date: \line(1,0){160}

\vspace{0.5cm}
Chairman/HoD

\vspace{1cm}
Signature: \line(1,0){160}

Date: \line(1,0){185}
\end{framed}
\pagebreak
\pagebreak
\underline{PART III}
\begin{framed}
\underline{\textbf{Dean, Faculty of Sciences}}

\line(1,0){100}  \,\, Approved for placement before BASAR.

\line(1,0){100}  \,\, Not Approved on the basis of following reasons

\vspace{2.5cm}

Signature: \line(1,0){160} \hfill Date: \line(1,0){130}

\rule{}

\underline{\textbf{Secretary BASAR}}

\line(1,0){100}  \,\, Approved from BASAR.

\line(1,0){100}  \,\, Not Approved on the basis of the following reasons

\vspace{2.5cm}

Signature: \line(1,0){160} \hfill Date: \line(1,0){130}

\rule{}

\underline{\textbf{Dean Faculty of Sciences}}

\textbf{Remarks:}

\begin{center}
\line(1,0){410}

\line(1,0){410}

\line(1,0){410}
\end{center}



\textbf{Signature:} \line(1,0){160} \hfill \textbf{Date:} \line(1,0){130}

 $\,$
\end{framed}

\underline{\textbf{APO Dean Faculty of Sciences}}
}
